==> libmicrofeed_0.0.5.tar.gz: libmicrofeed-0.0.5/microfeed-provider/microfeedprovider.h <==

#ifndef MICROFEEDPROVIDER_H
#define MICROFEEDPROVIDER_H

#define DBUS_API_SUBJECT_TO_CHANGE
#include <dbus/dbus.h>

/**
 * @addtogroup MicrofeedProvider
 * 
 * This module implementing a providers connection to DBus system is used in the publisher side.
 *
 * Provider instantiates existing publishers as requested by subscribers. In addition, a new or existing
 * publisher can also be instantiated using #microfeed_publisher_new function and then added into Provider
 * with the #microfeed_provider_add_publisher function. Provider also monitors name changes in the DBus and
 * informs its publishers by calling #microfeed_publisher_remove_subscriber when a potential subscriber has
 * terminated.
 * 
 * @{
 */

/**
 * An opaque datatype presenting a provider.
 */
typedef struct _MicrofeedProvider MicrofeedProvider;

/** @} */

#include <microfeed-provider/microfeedpublisher.h>
#include <microfeed-common/microfeedconfiguration.h>

/** 
 * @addtogroup MicrofeedProvider
 * @{
 */

typedef void (*MicrofeedProviderNoMorePublishersCallback)(MicrofeedProvider* provider, void* user_data);

typedef struct _MicrofeedProviderCallbacks {
	MicrofeedProviderNoMorePublishersCallback no_more_publishers;
	MicrofeedPublisherCallbacks publisher_callbacks;
} MicrofeedProviderCallbacks;

MicrofeedProvider* microfeed_provider_new(const char* bus_name, MicrofeedConfiguration* configuration, DBusConnection* connection, MicrofeedProviderCallbacks* callbacks, void* user_data);
void microfeed_provider_free(MicrofeedProvider* provider);
void microfeed_provider_add_publisher(MicrofeedProvider* provider, MicrofeedPublisher* publisher);
void microfeed_provider_remove_publisher(MicrofeedProvider* provider, MicrofeedPublisher* publisher);
DBusConnection* microfeed_provider_get_dbus_connection(MicrofeedProvider* provider);
const char* microfeed_provider_get_bus_name(MicrofeedProvider* provider);

/** @} */

#endif

==> libmicrofeed_0.0.7.tar.gz: libmicrofeed-0.0.7/microfeed-provider/microfeedprovider.h <==

#ifndef MICROFEEDPROVIDER_H
#define MICROFEEDPROVIDER_H

#define DBUS_API_SUBJECT_TO_CHANGE
#include <dbus/dbus.h>

/**
 * @addtogroup MicrofeedProvider
 * 
 * This module implementing a providers connection to DBus system is used in the publisher side.
 *
 * Provider instantiates existing publishers as requested by subscribers. In addition, a new or existing
 * publisher can also be instantiated using #microfeed_publisher_new function and then added into Provider
 * with the #microfeed_provider_add_publisher function. Provider also monitors name changes in the DBus and
 * informs its publishers by calling #microfeed_publisher_remove_subscriber when a potential subscriber has
 * terminated.
 * 
 * @{
 */

/**
 * An opaque datatype presenting a provider.
 */
typedef struct _MicrofeedProvider MicrofeedProvider;

/** @} */

#include <microfeed-provider/microfeedpublisher.h>
#include <microfeed-common/microfeedconfiguration.h>

/** 
 * @addtogroup MicrofeedProvider
 * @{
 */

typedef void (*MicrofeedProviderNoMorePublishersCallback)(MicrofeedProvider* provider, void* user_data);

typedef struct _MicrofeedProviderCallbacks {
	MicrofeedProviderNoMorePublishersCallback no_more_publishers;
	MicrofeedPublisherCallbacks publisher_callbacks;
} MicrofeedProviderCallbacks;

MicrofeedProvider* microfeed_provider_new(const char* bus_name, DBusConnection* connection, MicrofeedProviderCallbacks* callbacks, void* user_data);
void microfeed_provider_free(MicrofeedProvider* provider);
void microfeed_provider_add_publisher(MicrofeedProvider* provider, MicrofeedPublisher* publisher);
void microfeed_provider_remove_publisher(MicrofeedProvider* provider, MicrofeedPublisher* publisher);
DBusConnection* microfeed_provider_get_dbus_connection(MicrofeedProvider* provider);
const char* microfeed_provider_get_bus_name(MicrofeedProvider* provider);

/** @} */

#endif
